:mod:`pyramid_authsanity.sources`
=================================

.. automodule:: pyramid_authsanity.sources

Session Authentication Source
-----------------------------

.. autofunction:: SessionAuthSourceInitializer

Cookie Authentication Source
----------------------------

.. autofunction:: CookieAuthSourceInitializer

